==> centreon-web-24.10.14.tar.gz: centreon-web-24.10.14/packages/ui/src/Form/Inputs/Grid.tsx <==
import { makeStyles } from 'tss-react/mui';

import { InputPropsWithoutGroup } from './models';

import { Box, Typography } from '@mui/material';
import { FormikValues, useFormikContext } from 'formik';
import { isNotEmpty, isNotNil } from 'ramda';
import { getInput } from '.';

interface StylesProps {
  alignItems?: string;
  columns?: number;
  gridTemplateColumns?: string;
}

const useStyles = makeStyles<StylesProps>()(
  (theme, { columns, gridTemplateColumns, alignItems }) => ({
    gridFields: {
      alignItems: alignItems || 'flex-start',
      columnGap: theme.spacing(4),
      display: 'grid',
      gridTemplateColumns: gridTemplateColumns || `repeat(${columns}, 1fr)`,
      rowGap: theme.spacing(2)
    }
  })
);

const Grid = ({
  grid,
  hideInput
}: InputPropsWithoutGroup): JSX.Element | null => {
  const { classes, cx } = useStyles({
    alignItems: grid?.alignItems,
    columns: grid?.columns.length,
    gridTemplateColumns: grid?.gridTemplateColumns
  });

  const { values } = useFormikContext<FormikValues>();

  if (hideInput?.(values) ?? false) {
    return null;
  }

  const className = grid?.className || '';

  return (
    <div className={cx(classes.gridFields, className)}>
      {grid?.columns.map((field) => {
        const Input = getInput(field.type);

        const key =
          isNotNil(field.label) || isNotEmpty(field.label)
            ? field.label
            : field.additionalLabel;

        if (field.hideInput?.(values) ?? false) {
          return null;
        }

        return (
          <Box sx={{ width: '100%' }} key={key}>
            {field.additionalLabel && (
              <Typography
                sx={{ marginBottom: 0.5, color: 'primary.main' }}
                className={cx(field?.additionalLabelClassName)}
                variant="h6"
              >
                {field.additionalLabel}
              </Typography>
            )}
            <Input {...field} />
          </Box>
        );
      })}
    </div>
  );
};

export default Grid;

==> centreon-web-25.10.6.tar.gz: centreon-web-25.10.6/packages/ui/src/Form/Inputs/Grid.tsx <==
import { InputPropsWithoutGroup } from './models';

import { Box, Typography } from '@mui/material';
import { FormikValues, useFormikContext } from 'formik';
import { isNotEmpty, isNotNil } from 'ramda';
import { getInput } from '.';

const Grid = ({
  grid,
  hideInput
}: InputPropsWithoutGroup): JSX.Element | null => {
  const { values } = useFormikContext<FormikValues>();

  if (hideInput?.(values) ?? false) {
    return null;
  }

  const className = grid?.className || '';

  return (
    <div
      className={`${className} grid gap-3`}
      style={{
        gridTemplateColumns:
          className ? grid?.gridTemplateColumns || undefined : grid?.gridTemplateColumns ||
            `repeat(${grid?.columns.length || 1}, 1fr)`,
        alignItems: grid?.alignItems || 'flex-start'
      }}
    >
      {grid?.columns.map((field) => {
        const Input = getInput(field.type);

        const key =
          isNotNil(field.label) || isNotEmpty(field.label)
            ? field.label
            : field.additionalLabel;

        if (field.hideInput?.(values) ?? false) {
          return null;
        }

        return (
          <Box sx={{ width: '100%' }} key={key}>
            {field.additionalLabel && (
              <Typography
                sx={{ marginBottom: 0.5, color: 'primary.main' }}
                className={field?.additionalLabelClassName}
                variant="h6"
              >
                {field.additionalLabel}
              </Typography>
            )}
            <Input {...field} />
          </Box>
        );
      })}
    </div>
  );
};

export default Grid;
